@@ -61,9 +61,7 @@ public class SocialMailingUtil {
 		}
 
 		String sender = notification2Save.getSenderFullName();
-		if (notification2Save.getType() == NotificationType.DOCUMENT_WORKFLOW_STEP_REQUEST_TASK)
-			sender = "";
-
+	
 		String portalHost = portalURL.replaceAll("https://", "");
 		portalHost = portalHost.replaceAll("http://", "");
 
@@ -147,9 +145,7 @@ public class SocialMailingUtil {
 			}
 		}
 		String sender = notification2Save.getSenderFullName();
-		if (notification2Save.getType() == NotificationType.DOCUMENT_WORKFLOW_STEP_REQUEST_TASK)
-			sender = "";
-
+		
 		String portalHost = portalURL.replaceAll("https://", "");
 		portalHost = portalHost.replaceAll("http://", "");
 
@@ -307,7 +303,7 @@ public class SocialMailingUtil {
 			actionLink.append("\">").append(" Open Post").append("</a>");
 			break;
 		case POST_ALERT:
-			actionLink.append("\">").append("See this News").append("</a>");
+			actionLink.append("\">").append("See this Post").append("</a>");
 			break;
 		case REQUEST_CONNECTION:
 			actionLink.append("\">").append(" Go to Contacts Center").append("</a>");
@@ -499,7 +495,7 @@ public class SocialMailingUtil {
 							+ "["  + formatter.format(feed.getTime())  + "] " 
 							+ feed.getFullName() 
 							+ ": " 
-							+ (feedTextNoHtml.length() > 30 ? feedTextNoHtml.substring(0, 30) + " ..." : feedTextNoHtml)
+							+ (feedTextNoHtml.length() > 200 ? feedTextNoHtml.substring(0, 200) + " ..." : feedTextNoHtml)
 							+ "\n";
 
 
