@@ -13,13 +13,13 @@ import org.gcube.vomanagement.usermanagement.exception.UserRetrievalFault;
 import org.gcube.vomanagement.usermanagement.model.GCubeRole;
 import org.gcube.vomanagement.usermanagement.model.GCubeTeam;
 import org.gcube.vomanagement.usermanagement.util.ManagementUtils;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
 
 import com.liferay.counter.service.CounterLocalServiceUtil;
 import com.liferay.portal.DuplicateTeamException;
 import com.liferay.portal.kernel.exception.PortalException;
 import com.liferay.portal.kernel.exception.SystemException;
+import com.liferay.portal.kernel.log.Log;
+import com.liferay.portal.kernel.log.LogFactoryUtil;
 import com.liferay.portal.model.Role;
 import com.liferay.portal.model.Team;
 import com.liferay.portal.model.UserGroupRole;
@@ -35,7 +35,7 @@ public class LiferayRoleManager implements RoleManager {
 	/**
 	 * logger
 	 */
-	private static final Logger _log = LoggerFactory.getLogger(LiferayRoleManager.class);
+	private static final Log _log = LogFactoryUtil.getLog(LiferayRoleManager.class);
 	private static final String ADMINISTRATOR = "Administrator";
 	private static final int ROLE_TYPE = 2;  // role type. 1=regular, 2=site, 3=organization 
 
